@@ -25,7 +25,7 @@ use strict;
 use warnings;
 use utf8;
 
-our $VERSION = '1.199';
+our $VERSION = '1.200';
 
 use Time::HiRes ();
 use Quiq::Duration;
@@ -398,7 +398,7 @@ sub exec {
     # Returnwerte
 
     if ($capture) {
-        if ($capture eq 'stderr+stdout') {
+        if ($capture eq 'stdout,stderr') {
             my $stdout = $p->read($stdoutFile,-delete=>1);
             my $stderr = $p->read($stderrFile,-delete=>1);
             return ($stdout,$stderr);
@@ -641,7 +641,7 @@ sub _logCmd {
 
 =head1 VERSION
 
-1.199
+1.200
 
 =head1 AUTHOR
 
